==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QStencilOperation.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies stencil operation</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html">Qt3DRender::QStencilOperation</a></p>
 */
public class QStencilOperation extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilOperation.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilOperation(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilOperation() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#QStencilOperation">Qt3DRender::QStencilOperation::QStencilOperation(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilOperation(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilOperation instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#back-prop">Qt3DRender::QStencilOperation::back()const</a></p>
     */
    @io.qt.QtPropertyReader(name="back")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilOperationArguments back(){
        return back_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments back_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#front-prop">Qt3DRender::QStencilOperation::front()const</a></p>
     */
    @io.qt.QtPropertyReader(name="front")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilOperationArguments front(){
        return front_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments front_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilOperation(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QStencilOperation(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QStencilOperation instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.3.3-sources.jar: io/qt/qt3d/render/QStencilOperation.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies stencil operation</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html">Qt3DRender::QStencilOperation</a></p>
 */
public class QStencilOperation extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilOperation.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilOperation(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilOperation() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#QStencilOperation">Qt3DRender::QStencilOperation::QStencilOperation(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilOperation(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilOperation instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#back-prop">Qt3DRender::QStencilOperation::back()const</a></p>
     */
    @io.qt.QtPropertyReader(name="back")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilOperationArguments back(){
        return back_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments back_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#front-prop">Qt3DRender::QStencilOperation::front()const</a></p>
     */
    @io.qt.QtPropertyReader(name="front")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilOperationArguments front(){
        return front_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments front_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilOperation(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QStencilOperation(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QStencilOperation instance, QDeclarativeConstructor constructor);
    
}
